#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 type-errors
version:              0.2.0.2
visibility:           public
id:                   type-errors-0.2.0.2-3AtBgXehIXkHdG65hIU3jc
key:                  type-errors-0.2.0.2-3AtBgXehIXkHdG65hIU3jc
license:              BSD-3-Clause
copyright:            2019 Sandy Maguire
maintainer:           sandy@sandymaguire.me
author:               Sandy Maguire
homepage:             https://github.com/isovector/type-errors#readme
synopsis:             Tools for writing better type errors
description:
    Please see the README on GitHub at <https://github.com/isovector/type-errors#readme>

category:             Type
abi:                  9403ed431955b32ea55afa10394e3dd9
exposed:              True
exposed-modules:      Type.Errors
hidden-modules:       Paths_type_errors
import-dirs:          /usr/lib/ghc-9.6.6/site-local/type-errors-0.2.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/type-errors-0.2.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/type-errors-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-errors
hs-libraries:         HStype-errors-0.2.0.2-3AtBgXehIXkHdG65hIU3jc
depends:
    base-4.18.2.1 first-class-families-0.8.2.0-HzUnQisuAnjGuL9m7M0Ger
    syb-0.7.3-9ztCG0Q7snPDhcPoUMdZvi template-haskell-2.20.0.0
    th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3

haddock-interfaces:   /usr/share/doc/haskell-type-errors/html/type-errors.haddock
haddock-html:         /usr/share/doc/haskell-type-errors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

